==> 0.0.1.tar.gz: lib/src/field/forme_cupertino_switch.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/gestures.dart';
import 'package:forme/forme.dart';

class FormeCupertinoSwitch extends ValueField<bool, FormeCupertinoSwitchModel> {
  FormeCupertinoSwitch({
    FormeValueChanged<bool, FormeCupertinoSwitchModel>? onValueChanged,
    FormFieldValidator<bool>? validator,
    AutovalidateMode? autovalidateMode,
    bool initialValue = false,
    FormFieldSetter<bool>? onSaved,
    required String name,
    bool readOnly = false,
    Widget? label,
    FormeCupertinoSwitchModel? model,
    FormeErrorChanged<
            FormeValueFieldController<bool, FormeCupertinoSwitchModel>>?
        onErrorChanged,
    FormeFocusChanged<
            FormeValueFieldController<bool, FormeCupertinoSwitchModel>>?
        onFocusChanged,
    FormeFieldInitialed<
            FormeValueFieldController<bool, FormeCupertinoSwitchModel>>?
        onInitialed,
    Key? key,
    FormeDecoratorBuilder<bool>? decoratorBuilder,
  }) : super(
          decoratorBuilder: decoratorBuilder,
          onInitialed: onInitialed,
          nullValueReplacement: false,
          key: key,
          onFocusChanged: onFocusChanged,
          onErrorChanged: onErrorChanged,
          model: model ?? FormeCupertinoSwitchModel(),
          readOnly: readOnly,
          name: name,
          onValueChanged: onValueChanged,
          onSaved: onSaved,
          autovalidateMode: autovalidateMode,
          initialValue: initialValue,
          validator: validator,
          builder: (state) {
            bool readOnly = state.readOnly;
            bool value = state.value!;
            return CupertinoSwitch(
              value: value,
              onChanged: readOnly
                  ? null
                  : (v) {
                      state.didChange(v);
                      state.requestFocus();
                    },
              activeColor: state.model.activeColor,
              trackColor: state.model.trackColor,
              dragStartBehavior:
                  state.model.dragStartBehavior ?? DragStartBehavior.start,
            );
          },
        );
}

class FormeCupertinoSwitchModel extends FormeModel {
  final Color? activeColor;
  final Color? trackColor;
  final DragStartBehavior? dragStartBehavior;

  FormeCupertinoSwitchModel({
    this.activeColor,
    this.trackColor,
    this.dragStartBehavior,
  });

  FormeCupertinoSwitchModel copyWith(FormeModel oldModel) {
    FormeCupertinoSwitchModel old = oldModel as FormeCupertinoSwitchModel;
    return FormeCupertinoSwitchModel(
      activeColor: activeColor ?? old.activeColor,
      trackColor: trackColor ?? old.trackColor,
      dragStartBehavior: dragStartBehavior ?? old.dragStartBehavior,
    );
  }
}

==> 0.3.0.tar.gz: lib/src/field/forme_cupertino_switch.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/gestures.dart';
import 'package:forme/forme.dart';

class FormeCupertinoSwitch extends ValueField<bool, FormeCupertinoSwitchModel> {
  FormeCupertinoSwitch({
    bool initialValue = false,
    required String name,
    bool readOnly = false,
    Widget? label,
    FormeCupertinoSwitchModel? model,
    Key? key,
    FormeDecoratorBuilder<bool>? decoratorBuilder,
    FormeValueFieldListener<bool,
            FormeValueFieldController<bool, FormeCupertinoSwitchModel>>?
        listener,
    int? order,
  }) : super(
          order: order,
          listener: listener,
          decoratorBuilder: decoratorBuilder,
          key: key,
          model: model ?? FormeCupertinoSwitchModel(),
          readOnly: readOnly,
          name: name,
          initialValue: initialValue,
          builder: (state) {
            bool readOnly = state.readOnly;
            bool value = state.value;
            return CupertinoSwitch(
              value: value,
              onChanged: readOnly
                  ? null
                  : (v) {
                      state.didChange(v);
                      state.requestFocus();
                    },
              activeColor: state.model.activeColor,
              trackColor: state.model.trackColor,
              dragStartBehavior:
                  state.model.dragStartBehavior ?? DragStartBehavior.start,
            );
          },
        );
}

class FormeCupertinoSwitchModel extends FormeModel {
  final Color? activeColor;
  final Color? trackColor;
  final DragStartBehavior? dragStartBehavior;

  FormeCupertinoSwitchModel({
    this.activeColor,
    this.trackColor,
    this.dragStartBehavior,
  });

  FormeCupertinoSwitchModel copyWith(FormeModel oldModel) {
    FormeCupertinoSwitchModel old = oldModel as FormeCupertinoSwitchModel;
    return FormeCupertinoSwitchModel(
      activeColor: activeColor ?? old.activeColor,
      trackColor: trackColor ?? old.trackColor,
      dragStartBehavior: dragStartBehavior ?? old.dragStartBehavior,
    );
  }
}
